
# HPT Perl hook

sub filter {
# Called for processing every message while tossing. The following variables available:
#   $fromname - originating user name,
#   $fromaddr - message originating address,
#   $toname - destination user name,
#   $toaddr - message destination address (for netmail),
#   $area - message area (for echomail),
#   $subject - message subject line,
#   $date - message date and time,
#   $text - message text,
#   $attr - message attributes,
#   $pktfrom - address of originating pkt,
#   $secure - defined if the message received from secure link.
# Set $change to update $text, $subject, $fromaddr, $toaddr, $fromname, $toname, $attr.
# Set $kill for kill message.
# If returns non-empty string (reason), the message will be moved to badarea.

 use POSIX;
 if (defined($area))
 {
   append_to_mysql();
 }

  return "";
}

sub scan {
# Called while scanning messages (hpt scan or hpt pack). The following variables available:
#   $fromname - originating user name,
#   $fromaddr - message originating address,
#   $toname - destination user name,
#   $toaddr - message destination address (for netmail),
#   $area - message area (for echomail),
#   $subject - message subject line,
#   $date - message date and time,
#   $text - message text,
#   $attr - message attributes.
# Set $change to update $text, $subject, $fromaddr, $toaddr, $fromname, $toname, $attr.
# If returns non-empty string (reason), the message will not pack to downlinks.

 use POSIX;
 if (defined($area))
 { 
   append_to_mysql();
 }
 return "";
}


sub append_to_mysql {

  use POSIX;
  use locale;
  use Encode;
  use DBI;

  my $dsn = 'DBI:mysql:base:host:mysql_read_default_file=config_file';
  my $db_user_name = '';
  my $db_password = '';

  my $dbh = DBI->connect($dsn, $db_user_name, $db_password);

  if (defined($area))
  {
    my($rules_file,$msgid_addr,$msgid_number,$subj_recode,$text_recode,$fromname_recode,$toname_recode,$area_x);
    local(*F,*F1);

    $fromname_recode=encode("utf8", decode("cp866", $fromname));
    $toname_recode=encode("utf8", decode("cp866", $toname));
    $subj_recode=encode("utf8", decode("cp866", $subject));
    $text_recode=encode("utf8", decode("cp866", deltechinfo("$text")));

    $msgid_addr   =msgid_addr_sub("$text");
    $msgid_number =msgid_number_sub("$text");
    $reply_addr  =reply_addr_sub("$text");
    $reply_number=reply_number_sub("$text");

    $area_quote            = $dbh->quote($area);
    $fromname_recode_quote = $dbh->quote($fromname_recode);
    $fromaddr_quote        = $dbh->quote($fromaddr);
    $toname_recode_quote   = $dbh->quote($toname_recode);
    $subj_recode_quote     = $dbh->quote($subj_recode);
    $date_quote            = $dbh->quote($date);
    $msgid_addr_quote      = $dbh->quote($msgid_addr);
    $msgid_number_quote    = $dbh->quote($msgid_number);

    $reply_addr_quote      = $dbh->quote($reply_addr);
    $reply_number_quote    = $dbh->quote($reply_number);

    $text_recode_quote     = $dbh->quote($text_recode);


    my $sth2 = $dbh->prepare("insert into areadata (area,fromname,fromaddr,toname,subject,date,msgid_addr,msgid_num,reply_addr,reply_num,text) values ($area_quote,$fromname_recode_quote,$fromaddr_quote,$toname_recode_quote,$subj_recode_quote,$date_quote,$msgid_addr_quote,$msgid_number_quote,$reply_addr_quote,$reply_number_quote,$text_recode_quote)");
    $sth2->execute();
   }
}

sub deltechinfo 
{
  my(@temp,$temp_once,@newtemp,$i);

  @temp=split(/\r/,$_[0]);
  $i=0;
  foreach (@temp) {
    unless (/^\x01/i or /^SEEN-BY/i or /\* Origin:/i or /^---/i ) 
    {
      $newtemp[$i]=$_;
      $i++;
    }
  }
  $temp_once=join("\r",@newtemp);
  return $temp_once;
}

sub msgid_addr_sub {
  my(@temp,@msgid_str,$temp_once,$newtemp,$name,$value);

  @temp=split(/\r/,$_[0]);
  foreach (@temp) {
    if (/^\x01MSGID:/i) 
    {
      ($name, $value, $name)=split(/ /,$_);
    }
  }
  $value=~s/\//@/;
  return $value;
}

sub msgid_number_sub 
{
  my(@temp,@msgid_str,$temp_once,$newtemp,$name,$value);

  @temp=split(/\r/,$_[0]);
  foreach (@temp) {
    if (/^\x01MSGID:/i) 
    {
      ($name, $name, $value)=split(/ /,$_);
    }
  }
  return $value;
}



sub reply_addr_sub 
{
  my(@temp,@msgid_str,$temp_once,$newtemp,$name,$value);

  @temp=split(/\r/,$_[0]);
  foreach (@temp) {
    if (/^\x01REPLY:/i) 
    {
      ($name, $value, $name)=split(/ /,$_);
    }
  }
  $value=~s/\//@/;
  return $value;
}

sub reply_number_sub 
{
  my(@temp,@msgid_str,$temp_once,$newtemp,$name,$value);

  @temp=split(/\r/,$_[0]);
  foreach (@temp) {
    if (/^\x01REPLY:/i) 
    {
      ($name, $name, $value)=split(/ /,$_);
    }
  }
  return $value;
}
